@@ -5,7 +5,7 @@ use warnings;
 package Dist::Zilla::Plugin::Test::ReportPrereqs;
 # ABSTRACT: Report on prerequisite versions during automated testing
 
-our $VERSION = '0.020';
+our $VERSION = '0.022';
 
 use Dist::Zilla 4 ();
 
@@ -17,6 +17,7 @@ use Data::Section 0.200002 # encoding and bytes
   { installer => Sub::Exporter::ForMethods::method_installer }, '-setup';
 
 use Data::Dumper;
+use Moose::Util::TypeConstraints 'enum';
 
 sub mvp_multivalue_args {
     return qw( include exclude );
@@ -38,6 +39,12 @@ has verify_prereqs => (
     default => 1,
 );
 
+has version_extractor => (
+    is      => 'ro',
+    isa     => enum( [qw(ExtUtils::MakeMaker Module::Metadata)] ),
+    default => 'ExtUtils::MakeMaker',
+);
+
 sub register_prereqs {
     my $self = shift;
 
@@ -46,9 +53,9 @@ sub register_prereqs {
             phase => 'test',
             type  => 'requires',
         },
-        'Test::More'          => 0,
-        'ExtUtils::MakeMaker' => 0,
-        'File::Spec'          => 0,
+        'Test::More'             => 0,
+        $self->version_extractor => 0,
+        'File::Spec'             => 0,
     );
 
     $self->zilla->register_prereqs(
@@ -99,6 +106,17 @@ sub _munge_test {
     $guts =~ s{INSERT_INCLUDED_MODULES_HERE}{_format_list($self->included_modules)}e;
     $guts =~ s{INSERT_EXCLUDED_MODULES_HERE}{_format_list($self->excluded_modules)}e;
     $guts =~ s{INSERT_VERIFY_PREREQS_CONFIG}{$self->verify_prereqs ? 1 : 0}e;
+    $guts =~ s{VERSION_EXTRACTOR_MODULE}{$self->version_extractor}e;
+    if ( $self->version_extractor eq 'ExtUtils::MakeMaker' ) {
+        $guts
+          =~ s'VERSION_EXTRACTION'MM->parse_version( File::Spec->catfile($prefix, $file) )';
+
+    }
+    else { # Module::Metadata
+        $guts
+          =~ s'VERSION_EXTRACTION'Module::Metadata->new_from_file( File::Spec->catfile($prefix, $file) )->version';
+    }
+
     return $guts;
 }
 
@@ -175,6 +193,14 @@ __PACKAGE__->meta->make_immutable;
 #pod When set, installed versions of all 'requires' prerequisites are verified
 #pod against those specified.  Defaults to true, but requires CPAN::Meta to be installed.
 #pod
+#pod =head2 version_extractor
+#pod
+#pod Specifies the module to use to extract each installed prerequisite's
+#pod version.  Defaults to L<ExtUtils::MakeMaker>, which is recommended for most
+#pod situations.  It can also be specified as L<Module::Metadata>, which can be
+#pod useful if L<ExtUtils::MakeMaker>'s mechanism is too naive, or if
+#pod L<ExtUtils::MakeMaker> is not already a prerequisite of the distribution.
+#pod
 #pod =head1 SEE ALSO
 #pod
 #pod Other Dist::Zilla::Plugins do similar things in slightly different ways that didn't
@@ -197,7 +223,7 @@ Dist::Zilla::Plugin::Test::ReportPrereqs - Report on prerequisite versions durin
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -252,6 +278,14 @@ modules from the report (if you had a reason to do so).
 When set, installed versions of all 'requires' prerequisites are verified
 against those specified.  Defaults to true, but requires CPAN::Meta to be installed.
 
+=head2 version_extractor
+
+Specifies the module to use to extract each installed prerequisite's
+version.  Defaults to L<ExtUtils::MakeMaker>, which is recommended for most
+situations.  It can also be specified as L<Module::Metadata>, which can be
+useful if L<ExtUtils::MakeMaker>'s mechanism is too naive, or if
+L<ExtUtils::MakeMaker> is not already a prerequisite of the distribution.
+
 =head1 SEE ALSO
 
 Other Dist::Zilla::Plugins do similar things in slightly different ways that didn't
@@ -345,7 +379,7 @@ use warnings;
 
 use Test::More tests => 1;
 
-use ExtUtils::MakeMaker;
+use VERSION_EXTRACTOR_MODULE;
 use File::Spec;
 
 # from $version::LAX
@@ -460,7 +494,7 @@ for my $phase ( qw(configure build test runtime develop other) ) {
             my $req_string = $want eq 'any' ? 'any version required' : "version '$want' required";
 
             if ($prefix) {
-                my $have = MM->parse_version( File::Spec->catfile($prefix, $file) );
+                my $have = VERSION_EXTRACTION;
                 $have = "undef" unless defined $have;
                 push @reports, [$mod, $want, $have];
 
